@@ -2,6 +2,8 @@ import unittest
 import re
 from nose.tools import eq_, ok_
 from django.test.client import RequestFactory
+from django.core.cache import cache
+from fancy_cache.memory import find_urls
 
 from . import views
 
@@ -11,6 +13,9 @@ class TestViews(unittest.TestCase):
     def setUp(self):
         self.factory = RequestFactory()
 
+    def tearDown(self):
+        cache.clear()
+
     def test_render_home1(self):
         request = self.factory.get('/anything')
 
@@ -116,3 +121,51 @@ class TestViews(unittest.TestCase):
         ok_(re.findall('Random:\w+', response.content))
         random_string_3 = re.findall('Random:(\w+)', response.content)[0]
         eq_(random_string_2, random_string_3)
+
+    def test_remember_stats_all_urls(self):
+        request = self.factory.get('/anything')
+        response = views.home6(request)
+        eq_(response.status_code, 200)
+
+        # now ask the memory thing
+        match, = find_urls('/anything')
+        eq_(match[0], '/anything')
+        eq_(match[2]['hits'], 0)
+        eq_(match[2]['misses'], 1)
+
+        # second time
+        response = views.home6(request)
+        eq_(response.status_code, 200)
+        match, = find_urls('/anything')
+        eq_(match[0], '/anything')
+        eq_(match[2]['hits'], 1)
+        eq_(match[2]['misses'], 1)
+
+    def test_remember_stats_all_urls_looong_url(self):
+        request = self.factory.get(
+            '/something/really/long/to/start/with/right/here/since/this/will/'
+            'test/that/things/work/with/long/urls/too',
+            {
+                'line1': 'Bad luck, wind been blowing at my back',
+                'line2': "I was born to bring trouble to wherever I'm at",
+                'line3': "Got the number thirteen, tattooed on my neck",
+                'line4': "When the ink starts to itch, ",
+                'line5': "then the black will turn to red",
+            }
+        )
+        response = views.home6(request)
+        eq_(response.status_code, 200)
+
+        # now ask the memory thing
+        match, = find_urls()
+        ok_(match[0].startswith('/something/really'))
+        eq_(match[2]['hits'], 0)
+        eq_(match[2]['misses'], 1)
+
+        # second time
+        response = views.home6(request)
+        eq_(response.status_code, 200)
+        match, = find_urls([])
+        ok_(match[0].startswith('/something/really'))
+        eq_(match[2]['hits'], 1)
+        eq_(match[2]['misses'], 1)
